MCD triple_NN1
Gérer ( #ingénieur, #projet, #responsable! )

- Le champ ingénieur fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité Ingénieur.
- Le champ projet fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité Projet.
- Le champ à saisie obligatoire responsable est une clé étrangère. Il a migré directement à partir de l'entité Responsable en perdant son caractère identifiant.

Ingénieur ( ingénieur, nom ingénieur )

- Le champ ingénieur constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Ingénieur.
- Le champ nom ingénieur était déjà un simple attribut de l'entité Ingénieur.

Projet ( projet, libellé projet )

- Le champ projet constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Projet.
- Le champ libellé projet était déjà un simple attribut de l'entité Projet.

Responsable ( responsable, nom responsable )

- Le champ responsable constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Responsable.
- Le champ nom responsable était déjà un simple attribut de l'entité Responsable.